import Speech
from PyObjCTools.TestSupport import TestCase, min_os_level, min_sdk_level
import objc


class TestSFSpeechRecognitionTaskHelper(Speech.NSObject):
    def speechRecognitionTask_didFinishSuccessfully_(self, a, b):
        pass


class TestSFSpeechRecognitionTask(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(Speech.SFSpeechRecognitionTaskState)

    def test_constants(self):
        self.assertEqual(Speech.SFSpeechRecognitionTaskStateStarting, 0)
        self.assertEqual(Speech.SFSpeechRecognitionTaskStateRunning, 1)
        self.assertEqual(Speech.SFSpeechRecognitionTaskStateFinishing, 2)
        self.assertEqual(Speech.SFSpeechRecognitionTaskStateCanceling, 3)
        self.assertEqual(Speech.SFSpeechRecognitionTaskStateCompleted, 4)

    @min_sdk_level("10.15")
    def test_protocols(self):
        objc.protocolNamed("SFSpeechRecognitionTaskDelegate")

    def test_methods(self):
        self.assertArgIsBOOL(
            TestSFSpeechRecognitionTaskHelper.speechRecognitionTask_didFinishSuccessfully_,
            1,
        )

    @min_os_level("10.15")
    def test_methods10_15(self):
        self.assertResultIsBOOL(Speech.SFSpeechRecognitionTask.isFinishing)

        self.assertResultIsBOOL(Speech.SFSpeechRecognitionTask.isCancelled)



import Speech
from PyObjCTools.TestSupport import TestCase, min_os_level, min_sdk_level
import objc


class TestSFSpeechRecognizerHelper(Speech.NSObject):
    def speechRecognizer_availabilityDidChange_(self, a, b):
        pass


class TestSFSpeechRecognizer(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(Speech.SFSpeechRecognizerAuthorizationStatus)

    def test_constants(self):
        self.assertEqual(Speech.SFSpeechRecognizerAuthorizationStatusNotDetermined, 0)
        self.assertEqual(Speech.SFSpeechRecognizerAuthorizationStatusDenied, 1)
        self.assertEqual(Speech.SFSpeechRecognizerAuthorizationStatusRestricted, 2)
        self.assertEqual(Speech.SFSpeechRecognizerAuthorizationStatusAuthorized, 3)

    @min_sdk_level("10.15")
    def test_protocols(self):
        objc.protocolNamed("SFSpeechRecognizerDelegate")

    def test_methods(self):
        self.assertArgIsBOOL(
            TestSFSpeechRecognizerHelper.speechRecognizer_availabilityDidChange_, 1
        )

    @min_os_level("10.15")
    def test_methods10_15(self):
        self.assertArgIsBlock(
            Speech.SFSpeechRecognizer.requestAuthorization_, 0, b"v" + objc._C_NSInteger
        )

        self.assertResultIsBOOL(Speech.SFSpeechRecognizer.isAvailable)

        self.assertArgIsBlock(
            Speech.SFSpeechRecognizer.recognitionTaskWithRequest_resultHandler_,
            1,
            b"v@@",
        )



# This file is generated by objective.metadata
#
# Last update: Sun Feb 20 19:24:48 2022
#
# flake8: noqa

import objc, sys
from typing import NewType

if sys.maxsize > 2**32:

    def sel32or64(a, b):
        return b

else:

    def sel32or64(a, b):
        return a


if objc.arch == "arm64":

    def selAorI(a, b):
        return a

else:

    def selAorI(a, b):
        return b


misc = {}
constants = """$$"""
enums = """$SFSpeechRecognitionTaskHintConfirmation@3$SFSpeechRecognitionTaskHintDictation@1$SFSpeechRecognitionTaskHintSearch@2$SFSpeechRecognitionTaskHintUnspecified@0$SFSpeechRecognitionTaskStateCanceling@3$SFSpeechRecognitionTaskStateCompleted@4$SFSpeechRecognitionTaskStateFinishing@2$SFSpeechRecognitionTaskStateRunning@1$SFSpeechRecognitionTaskStateStarting@0$SFSpeechRecognizerAuthorizationStatusAuthorized@3$SFSpeechRecognizerAuthorizationStatusDenied@1$SFSpeechRecognizerAuthorizationStatusNotDetermined@0$SFSpeechRecognizerAuthorizationStatusRestricted@2$"""
misc.update(
    {
        "SFSpeechRecognitionTaskHint": NewType("SFSpeechRecognitionTaskHint", int),
        "SFSpeechRecognitionTaskState": NewType("SFSpeechRecognitionTaskState", int),
        "SFSpeechRecognizerAuthorizationStatus": NewType(
            "SFSpeechRecognizerAuthorizationStatus", int
        ),
    }
)
misc.update({})
r = objc.registerMetaDataForSelector
objc._updatingMetadata(True)
try:
    r(
        b"NSObject",
        b"speechRecognitionDidDetectSpeech:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"speechRecognitionTask:didFinishRecognition:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"speechRecognitionTask:didFinishSuccessfully:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"Z"}},
        },
    )
    r(
        b"NSObject",
        b"speechRecognitionTask:didHypothesizeTranscription:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"speechRecognitionTaskFinishedReadingAudio:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"speechRecognitionTaskWasCancelled:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"speechRecognizer:availabilityDidChange:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"Z"}},
        },
    )
    r(
        b"SFSpeechRecognitionRequest",
        b"requiresOnDeviceRecognition",
        {"retval": {"type": b"Z"}},
    )
    r(
        b"SFSpeechRecognitionRequest",
        b"setRequiresOnDeviceRecognition:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(
        b"SFSpeechRecognitionRequest",
        b"setShouldReportPartialResults:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(
        b"SFSpeechRecognitionRequest",
        b"shouldReportPartialResults",
        {"retval": {"type": b"Z"}},
    )
    r(b"SFSpeechRecognitionResult", b"isFinal", {"retval": {"type": b"Z"}})
    r(b"SFSpeechRecognitionTask", b"isCancelled", {"retval": {"type": b"Z"}})
    r(b"SFSpeechRecognitionTask", b"isFinishing", {"retval": {"type": b"Z"}})
    r(b"SFSpeechRecognizer", b"isAvailable", {"retval": {"type": b"Z"}})
    r(
        b"SFSpeechRecognizer",
        b"recognitionTaskWithRequest:resultHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"SFSpeechRecognizer",
        b"requestAuthorization:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"q"}},
                    }
                }
            }
        },
    )
    r(
        b"SFSpeechRecognizer",
        b"setSupportsOnDeviceRecognition:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(b"SFSpeechRecognizer", b"supportsOnDeviceRecognition", {"retval": {"type": b"Z"}})
finally:
    objc._updatingMetadata(False)
expressions = {}

# END OF FILE



import Speech
from PyObjCTools.TestSupport import TestCase, min_os_level


class TestSFSpeechRecognitionRequest(TestCase):
    @min_os_level("10.15")
    def test_methods10_15(self):
        self.assertResultIsBOOL(
            Speech.SFSpeechRecognitionRequest.shouldReportPartialResults
        )
        self.assertArgIsBOOL(
            Speech.SFSpeechRecognitionRequest.setShouldReportPartialResults_, 0
        )
        self.assertResultIsBOOL(
            Speech.SFSpeechRecognitionRequest.requiresOnDeviceRecognition
        )
        self.assertArgIsBOOL(
            Speech.SFSpeechRecognitionRequest.setRequiresOnDeviceRecognition_, 0
        )



import Speech
from PyObjCTools.TestSupport import TestCase


class TestSFSpeechRecognitionTaskHint(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(Speech.SFSpeechRecognitionTaskHint)

    def test_constants(self):
        self.assertEqual(Speech.SFSpeechRecognitionTaskHintUnspecified, 0)
        self.assertEqual(Speech.SFSpeechRecognitionTaskHintDictation, 1)
        self.assertEqual(Speech.SFSpeechRecognitionTaskHintSearch, 2)
        self.assertEqual(Speech.SFSpeechRecognitionTaskHintConfirmation, 3)
